@@ -3,6 +3,7 @@
 #!/usr/bin/python3 # noqa: E265
 import argparse
 
+from .download import DownloadCommmand
 from .apps import AppsCommmand
 from .auth import AuthCommand
 from .deploy import DeployCommand
@@ -21,6 +22,7 @@ def main():
     CreateCommand.register_subcommand(commands_parser)
     DeployCommand.register_subcommand(commands_parser)
     AppsCommmand.register_subcommand(commands_parser)
+    DownloadCommmand.register_subcommand(commands_parser)
 
     args = parser.parse_args()
 
