@@ -1,48 +1,58 @@
 """
 Basic tools to build and evaluate a model
 """
-from typing import Callable, List, Tuple, Union
+from typing import List, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
 import torch
+from deepchain import log
 from sklearn.metrics import accuracy_score, confusion_matrix, roc_auc_score
 from torch.utils.data import DataLoader, TensorDataset
 
 
-def dataloader_from_numpy(
-    X: np.ndarray, y: np.array, batch_size: int = None
+def classification_dataloader_from_numpy(
+    x: np.ndarray, y: np.array, batch_size: int = 32
 ) -> DataLoader:
+    """Build a dataloader from numpy for classification problem
+
+    This dataloader is use only for classification. It detects automatically the class of
+    the problem (binary or multiclass classification)
+    Args:
+        x (np.ndarray): [description]
+        y (np.array): [description]
+        batch_size (int, optional): [description]. Defaults to None.
+
+    Returns:
+        DataLoader: [description]
     """
-    function that build a torch dataset
-    """
-    tensor_set = TensorDataset(torch.tensor(X).float(), torch.tensor(y).float())
+    n_class: int = len(np.unique(y))
+    if n_class > 2:
+        log.info("This is a classification problem with %s classes", n_class)
+    else:
+        log.info("This is a binary classification problem")
+
+    # y is float for binary classification, int for multiclass
+    y_tensor = torch.tensor(y).long() if len(np.unique(y)) > 2 else torch.tensor(y).float()
+    tensor_set = TensorDataset(torch.tensor(x).float(), y_tensor)
     loader = DataLoader(tensor_set, batch_size=batch_size)
     return loader
 
 
-def model_evaluation_accuracy(
-    dataloader: DataLoader, model
-) -> Tuple[np.array, np.array]:
-    """
-    Make prediction for test data
+def model_evaluation_accuracy(y_true: np.array, y_hat: np.array):
+    """Make prediction for test data
+    Work only for bibary classification problem
+
+
     Args:
         dataloader: a torch dataloader containing dataset to be evaluated
         model : a callable trained model with a predict method
     """
-    prediction, truth = [], []
-    for X, y in dataloader:
-        y_hat = model.predict(X)
-        prediction += y_hat.detach().numpy().flatten().tolist()
-        truth += y.detach().numpy().flatten().tolist()
-
-    prediction, truth = np.array(prediction), np.array(truth)
-
-    acc_score = accuracy_score(truth, (prediction > 0.5).astype(int))
-    auc = roc_auc_score(truth, prediction)
+    acc_score = accuracy_score(y_true, (y_hat > 0.5).astype(int))  # type: ignore
+    auc = roc_auc_score(y_true, y_hat)
     print(f" Test :  accuracy score : {acc_score:0.2f} - AUC score : {auc:0.2f}  ")
 
-    return prediction, truth
+    return
 
 
 def confusion_matrix_plot(
@@ -79,7 +89,7 @@ def confusion_matrix_plot(
                 verticalalignment="center",
                 size=25,
             )
-    cb = fig.colorbar(res)
+    _ = fig.colorbar(res)
     alphabet = class_
 
     plt.xticks(range(width), alphabet[:width])
